@@ -2,6 +2,7 @@ from collections import namedtuple
 from functools import partial, wraps
 import codecs
 from glob import glob
+from itertools import chain, groupby
 import logging
 import shutil
 from lxml import etree
@@ -107,6 +108,34 @@ class CoreNLPDoc(object):
     def collapsed_cc_deps(self, sent):
         return self._dparse(sent, dep_type='collapsed-ccprocessed-dependencies')
 
+class CoreNLPField(object):
+    def __init__(self, field):
+        self.field = field
+
+    def sents(self, key='word'):
+        sentences = self.field.get(key, [])
+        return [[tok.replace(u'\u237D', u' ') for tok in sent.split(u" ")]
+                for sent in sentences]
+
+    def flat(self, key='word'):
+        return list(chain(*self.sents(key)))
+
+    def ner(self, key='word', flat=True):
+        def extract(ners, tokens):
+            ner_groups = []
+            for s, g in groupby(enumerate(ners), lambda x: x[1]):
+                if s == 'O': continue
+                group = list(g)
+                ner_groups.append((s, u' '.join(tokens[group[0][0]:group[-1][0]+1])))
+            return ner_groups
+
+        if flat:
+            return extract(self.flat('ner'), self.flat(key))
+        else:
+            return [extract(ners, tokens)
+                    for ners, tokens in zip(self.sents('ner'), self.sents(key))]
+
+
 def parse_texts(texts, jar_dir, prop_file=None, keep_files=False):
     temp_dir = mkdtemp("corenlp")
     logging.debug("Creating temporary dir for input texts: {}".format(temp_dir))
